#---------------------------------------------
# abstand_ton.py
# Das Programm misst den Abstand zum nächsten Hindernis
# vor dem Ultraschallsensor und gibt die Entfernung
# als Ton aus. Wenn der Schalter (an GPIO Pin 3) geschlossen wird,
# wird das Programm beendet und der Computer heruntergefahren.
#
# Michael Weigend
# Raspberry Pi fuer Kids
# Kapitel 14, Projekt 38
# 1.11.2014
#----------------------------------------------

import time, os
from RPi import GPIO


TRIGGER = 8
ECHO = 10
SCHALTER = 3
TIMEOUT = 0.1

def init_gpio():
    # Initialisiert die Schnittstelle zum GPIO
    GPIO.setwarnings(False)
    GPIO.setmode(GPIO.BOARD)
    GPIO.setup(TRIGGER, GPIO.OUT)
    GPIO.setup(ECHO, GPIO.IN)
    GPIO.output(TRIGGER, False)
    time.sleep(1)

def sende_impuls():
    # Sendet Impuls der Länge 20 Mikrosekunden
    GPIO.output(TRIGGER, True)
    time.sleep(0.00002)
    GPIO.output(TRIGGER, False)

def empfange_echo():
    # Liefert Länge des Echo-Signals des Sensors
    while GPIO.input(ECHO)== 0:
        pass
    start = time.time()
    while GPIO.input(ECHO)== 1:
        pass
    stop = time.time()
    return stop - start

def berechne_abstand():
    # Liefert Abstand in cm
    sende_impuls()
    zeit = empfange_echo()
    abstand = (zeit * 34000)/2
    return round(abstand)
    
# Hauptprogramm
init_gpio()
while GPIO.input(SCHALTER):                 #1
    pause = berechne_abstand()/100          #2
    os.system('aplay sounds/boing.wav')     #3
    time.sleep(pause)                       #4
os.system('halt')                           #5
    
          
